@@ -32,7 +32,10 @@ import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdktf/tf-module-stack", "6.0.7", __name__[0:-6], "tf-module-stack@6.0.7.jsii.tgz"
+    "@cdktf/tf-module-stack",
+    "6.0.11",
+    __name__[0:-6],
+    "tf-module-stack@6.0.11.jsii.tgz",
 )
 
 __all__ = [
